@@ -15,6 +15,10 @@ def write_conllx(sentence_list: List[SentenceX], output_fd):
                 sentence_id = sentence_id if sentence_id else str(uuid.uuid4())
                 meta = copy.deepcopy(sentence.meta)
                 meta.update({"id": sentence_id})
+
+                # remove None-valued meta
+                meta = {k: v for k, v in meta.items() if v is not None}
+
                 meta_string = json.dumps(meta, ensure_ascii=False)
                 output_fd.write("{}\n".format("\t".join(["#", meta_string])))
 
