@@ -16,6 +16,16 @@ def conllx_to_offset(
     input_text = sentence_data.word_lines
     tags_seq = sentence_data.get_attribute_by_index(attr_index)
 
+    try:
+        role_seq = sentence_data.get_attribute_by_index(1)
+    except IndexError:
+        role_seq = []
+
+    try:
+        group_seq = sentence_data.get_attribute_by_index(2)
+    except IndexError:
+        group_seq = []
+
     failed = False
     meta = copy.deepcopy(sentence_data.meta)
 
@@ -23,6 +33,8 @@ def conllx_to_offset(
         seq = decoder.to_offset(
             tags_seq,
             input_text,
+            role_seq,
+            group_seq,
             label=meta.pop("label", None),
             id=sentence_data.id,
             **meta
