@@ -1,4 +1,4 @@
-from sklearn import metrics
+from sklearn import metrics  # pytype: disable=import-error
 
 
 class TagLevelEvaluator(object):
@@ -7,8 +7,8 @@ class TagLevelEvaluator(object):
         self.y_pred = []
 
     def get_score(self, **kwargs):
-        if 'average' not in kwargs:
-            kwargs['average'] = 'weighted'
+        if "average" not in kwargs:
+            kwargs["average"] = "weighted"
         return metrics.f1_score(self.y_true, self.y_pred, **kwargs)
 
     def process_one_batch(self, y_true, y_pred):
@@ -18,14 +18,8 @@ class TagLevelEvaluator(object):
 
 if __name__ == "__main__":
     evaluator = TagLevelEvaluator()
-    evaluator.process_one_batch(
-        ['我是谁', '呢呢'],
-        ['我是', '谁', '呢呢']
-    )
-    evaluator.process_one_batch(
-        ['我是谁', '呢呢'],
-        ['我是', '谁', '呢呢']
-    )
+    evaluator.process_one_batch(["我是谁", "呢呢"], ["我是", "谁", "呢呢"])
+    evaluator.process_one_batch(["我是谁", "呢呢"], ["我是", "谁", "呢呢"])
 
     score = evaluator.get_score()
     print(score)
