@@ -68,6 +68,11 @@ class CorpusStatistics:
         domain_list = [doc.domain for doc in corpus]
         return Counter(domain_list)
 
+    @classmethod
+    def _collection_attr(cls, corpus: "Corpus", attr: str) -> Counter:
+        attr_list = [getattr(doc, attr) for doc in corpus]
+        return Counter(attr_list)
+
     @classmethod
     def _collect_function(cls, corpus: "Corpus") -> Counter:
         function_list = [doc.function for doc in corpus]
